function e = ehatnu( norm_r, rAr, norm_Ar, nu)
%EHATNU A-norm error estimate for a set of approximate solutions
%
%   e = ehatnu(norm_r,rAr,norm_Ar,nu) computes the A-norm error estimate for a
%   set of solutions (x(:,i),i=1,...,k) of a positive definite linear system.
%
%   The input parameters norm_r, rAr and norm_Ar are k-vectors such that
%	norm_r(i) = norm(r(:,i)), where r(:,i)=b-A*x(:,i)
%	rAr(i) = r(:,i)'*A*r(:,i)
%	norm_Ar(i) = norm(A*r(:,i)) or norm(A'*r(:,i)) 
%   nu is the index of the estimate (real number, default 3).
%
%   See also enu, enutik, etanu, etanutik.

% This function computes the estimate ehat_nu defined in eq. (16) of the paper
%   C. Brezinski, G. Rodriguez, and S. Seatzu.
%   Error estimates for linear systems with applications to regularization.
%   Numer. Algorithms, 49(1-4):85-104, 2008.
% or in eq. (1.4) of the paper
%   C. Brezinski, G. Rodriguez, and S. Seatzu.
%   Error estimates for the regularization of least squares problems.
%   Numer. Algorithms, 2009. In press. 

%	Giuseppe Rodriguez,  31-01-08
% 	Email: rodriguez@unica.it

if nargin < 4,  nu = 3;  end
e = (norm_r.^(nu+1)) .* (abs(rAr).^(2-nu)) .* (norm_Ar.^(nu-3));

