function e = enu( norm_r, rAr, norm_Ar, nu)
%ENU	error estimate for a set of approximate solutions (square case)
%
%   e = enu(norm_r,rAr,norm_Ar,nu) computes the error estimate for a set of
%   solutions (x(:,i),i=1,...,k) of a square nonsingular linear system.
%
%   The input parameters norm_r, rAr and norm_Ar are k-vectors such that
%	norm_r(i) = norm(r(:,i)), where r(:,i)=b-A*x(:,i)
%	rAr(i) = r(:,i)'*A*r(:,i)
%	norm_Ar(i) = norm(A*r(:,i)) or norm(A'*r(:,i)) 
%   nu is the index of the estimate (real number, default 3).
%
%   See also ehatnu, enutik, etanu, etanutik.

% This function computes the estimates e_nu and etilde_nu defined in eqs. (9)
% and (11) of the paper 
%   C. Brezinski, G. Rodriguez, and S. Seatzu.
%   Error estimates for linear systems with applications to regularization.
%   Numer. Algorithms, 49(1-4):85-104, 2008.
% or in eqs. (1.2) and (1.3) of the paper
%   C. Brezinski, G. Rodriguez, and S. Seatzu.
%   Error estimates for the regularization of least squares problems.
%   Numer. Algorithms, 2009. In press. 

%	Giuseppe Rodriguez,  31-01-08
% 	Email: rodriguez@unica.it

if nargin < 4,  nu = 3;  end
e = (norm_r.^(nu-1)) .* (abs(rAr).^(3-nu)) .* (norm_Ar.^(nu-4));

